Overview – Samplics Documentation
Description: Documentation of the Python package Samplics for statistical design and analysis of complex samples

# Overview

SAE techniques can be considered as extensions of the survey estimation techniques that only use the sample data to produce estimates. Note that we include model assisted techniques such as the Generalized Regression (GREG) estimator in this category. These are often referred to as the direct estimates. In some applications, sample sizes are not large enough to produce reliable direct estimates for the domains of interest. In these situations, one possible way to improve the domain level estimates is to use SAE techniques which require availability of auxiliary information. Depending on the SAE method used, the auxiliary information needs to be available at the domains aggregated level or for non-sampled observations in the target population. SAE techniques produce modeled estimates of parameters of interest. There are two main categories of SAE methods that are the area level and the unit level, discussed in this tutorial.

Section 1: Area level modeling
Section 2: Unit level modeling

Generalized linear mixed model are the statistical framework used to develop the SAE methods, for an introduction to GLMM see McCulloch, Searle, and Neuhaus (2008). For a comprehensive review of the small area estimation models and its applications, see Rao and Molina (2015).

## References

McCulloch, C E, S R Searle, and J M Neuhaus. 2008. Generalized, Linear, and Mixed Models. New York: John Wiley; Sons.
Rao, J. N. K., and I Molina. 2015. Small Area Estimation, 2nd edn. John Wiley & Sons, Hoboken, New Jersey.